import requests
from e2enetworks.constants import BASE_GPU_URL


class Dataset:
    def __init__(self, team_id, project_id, credentials):
        self.team_id = team_id
        self.project_id = project_id
        self.credentials = credentials

    def create(self, bucket_name, bucket_type=None):
        pass

    def get(self, bucket_name):
        pass

    def list(self):
        url = f"{BASE_GPU_URL}teams/{self.team_id}/projects/{self.project_id}/datasets/" \
              f"eos-bucket-selection-list/?apikey={self.credentials.access_key}"
        payload = ""
        headers = {
            'Authorization': f'Bearer {self.credentials.api_token}'
        }
        response = requests.request("GET", url, headers=headers, data=payload)

        print(response.json()['data'])

    def delete(self, bucket_name):
        pass



class init:
    def __init__(self, access_key, api_token):
        self.access_key = access_key
        self.api_token = api_token

    @classmethod
    def api_token(cls):
        return cls.api_token

    @classmethod
    def access_key(cls):
        return cls.access_key



class EndPoint:
    def __init__(self, model=None):
        self.model = model

    def create(self, sku_id=None, storage_url=None, replica=None,):
        pass

    def get(self, endpoint_id):
        pass

    def list(self):
        pass

    def delete(self, endpoint_id):
        pass



import json
import requests
from e2enetworks.constants import BASE_GPU_URL


class Model:
    def __init__(self, team_id, project_id, credentials):
        self.team_id = team_id
        self.project_id = project_id
        self.credentials = credentials

    def create(self, name, bucket_type, bucket_name, model_type):
        payload = json.dumps({
            "name": name,
            "type": bucket_type,
            "bucket_name": bucket_name,
            "model_type": model_type
        })
        url = f"{BASE_GPU_URL}teams/{self.team_id}/projects/{self.project_id}/model/" \
              f"?apikey={self.credentials.access_key}"

        headers = {
            'Content-Type': 'application/json',
            'Authorization': f'Bearer {self.credentials.api_token}'
        }
        response = requests.request("POST", url, headers=headers, data=payload)

        print(response.json())

    def get(self, model_id):
        url = f"{BASE_GPU_URL}teams/{self.team_id}/projects/{self.project_id}/model/{model_id}" \
              f"?apikey={self.credentials.access_key}"
        payload = ""
        headers = {
            'Authorization': f'Bearer {self.credentials.api_token}'
        }
        response = requests.request("GET", url, headers=headers, data=payload)
        print(response.json())

    def list(self):
        url = f"{BASE_GPU_URL}teams/{self.team_id}/projects/{self.project_id}/model/" \
              f"?apikey={self.credentials.access_key}"
        payload = ""
        headers = {
            'Authorization': f'Bearer {self.credentials.api_token}'
        }
        response = requests.request("GET", url, headers=headers, data=payload)
        print(response.json())

    def delete(self, model_id):
        url = f"{BASE_GPU_URL}teams/{self.team_id}/projects/{self.project_id}/model/{model_id}" \
              f"?apikey={self.credentials.access_key}"
        payload = ""
        headers = {
            'Authorization': f'Bearer {self.credentials.api_token}'
        }
        response = requests.request("DELETE", url, headers=headers, data=payload)
        print(response.json())



from setuptools import setup
from setuptools import find_packages
from os import path

version = "0.0.10"
install_requires = [

]
# read the contents of your README file

this_directory = path.abspath(path.dirname(__file__))
with open(path.join(this_directory, "README.rst")) as f:
    long_description = f.read()

setup(
    name="e2enetworks",
    version=version,
    description="E2E Networks Plugins",
    long_description=long_description,
    long_description_content_type="text/x-rst",
    author="Dhananjay Singh",
    author_email="djs091298@gmail.com",
    license="MIT",
    python_requires=">=2.7, !=3.0.*, !=3.1.*, !=3.2.*, !=3.3.*",
    classifiers=[
        "Development Status :: 3 - Alpha",
        "Environment :: Plugins",
        "Intended Audience :: System Administrators",
        "License :: OSI Approved :: Apache Software License",
        "Operating System :: POSIX :: Linux",
        "Programming Language :: Python",
        "Programming Language :: Python :: 2",
        "Programming Language :: Python :: 2.7",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.4",
        "Programming Language :: Python :: 3.5",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Topic :: Internet :: WWW/HTTP",
        "Topic :: Security",
        "Topic :: System :: Installation/Setup",
        "Topic :: System :: Networking",
        "Topic :: System :: Systems Administration",
        "Topic :: Utilities",
    ],
    packages=find_packages(),
    include_package_data=True,
    install_requires=install_requires,
    # entry_points={
    #     "certbot.plugins": [
    #         "dns-e2econfig = certbot_dns_e2econfig.dns_e2econfig:Authenticator"
    #     ]
    # },
    #test_suite="certbot_dns_e2econfig",
)



from e2enetworks.cloud.aiplatform.Model import Model
from e2enetworks.cloud.aiplatform.EndPoint import EndPoint
from e2enetworks.cloud.aiplatform.Dataset import Dataset
from e2enetworks.cloud.aiplatform.init import init
